@@ -1,8 +1,9 @@
 import re
-from django.conf import settings
 from django.conf.urls.defaults import patterns, url
 from django.core.exceptions import ImproperlyConfigured
 
+from staticfiles.conf import settings
+
 urlpatterns = []
 
 
@@ -24,9 +25,11 @@ def static(prefix, view='django.views.static.serve', **kwargs):
     elif not prefix:
         raise ImproperlyConfigured("Empty static prefix not permitted")
     return patterns('',
-        url(r'^%s(?P<path>.*)$' % re.escape(prefix.lstrip('/')), view, kwargs=kwargs),
+        url(r'^%s(?P<path>.*)$' % re.escape(prefix.lstrip('/')),
+            view, kwargs=kwargs),
     )
 
+
 def staticfiles_urlpatterns(prefix=None):
     """
     Helper function to return a URL pattern for serving static files.
